@@ -20,15 +20,16 @@
  * along with this package. If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-#include "about.h"
-#include "mainwindow.h"
-#include "ui_mainwindow.h"
-
+#include <QDebug>
 #include <QFileDialog>
 #include <QScrollBar>
+#include <QTemporaryDir>
 #include <QTextStream>
+
+#include "about.h"
 #include "unistd.h"
-#include <QDebug>
+#include "mainwindow.h"
+#include "ui_mainwindow.h"
 
 MainWindow::MainWindow(const QStringList& args) :
     ui(new Ui::MainWindow)
@@ -186,59 +187,46 @@ void MainWindow::setup()
 QString MainWindow::buildOptionList()
 {
     QString options("-N ");
-    if (ui->cb_encrypt->isChecked()) {
+    if (ui->cb_encrypt->isChecked())
         options += "-E ";
-    }
-    if (ui->cb_gpt->isChecked()) {
+    if (ui->cb_gpt->isChecked())
         options += "-g ";
-    }
-    if (ui->cb_keep->isChecked()) {
+    if (ui->cb_keep->isChecked())
         options += "-k ";
-    }
     if (ui->cb_pretend->isChecked()) {
         options += "-p ";
-        if (ui->sliderVerbosity->value() == 0) { // add Verbosity of not selected, workaround for LUM bug
+        if (ui->sliderVerbosity->value() == 0) // add Verbosity of not selected, workaround for LUM bug
             ui->sliderVerbosity->setSliderPosition(1);
-        }
     }
-    if (ui->cb_save_boot->isChecked()) {
+    if (ui->cb_save_boot->isChecked())
         options += "-S ";
-    }
-    if (ui->cb_update->isChecked()) {
+    if (ui->cb_update->isChecked())
         options += "-u ";
-    }
-    if (ui->cb_set_pmbr_boot->isChecked()) {
+    if (ui->cb_set_pmbr_boot->isChecked())
         options += "--gpt-pmbr ";
-    }
-    if (ui->spinBoxEsp->value() != 50) {
+    if (ui->spinBoxEsp->value() != 50)
         options += "--esp-size=" + ui->spinBoxEsp->cleanText() + " ";
-    }
-    if (ui->spinBoxSize->value() < 100) {
+    if (ui->spinBoxSize->value() < 100)
         options += "--size=" + ui->spinBoxSize->cleanText() + " ";
-    }
-    if (!ui->edit_label->text().isEmpty()) {
+    if (!ui->edit_label->text().isEmpty())
         options += " --label=" + ui->edit_label->text() + " ";
-    }
-    if (ui->cb_force_usb->isChecked()) {
+    if (ui->cb_force_usb->isChecked())
         options += "--force=usb ";
-    }
-    if (ui->cb_force_automount->isChecked()) {
+    if (ui->cb_force_automount->isChecked())
         options += "--force=automount ";
-    }
-    if (ui->cb_force_makefs->isChecked()) {
+    if (ui->cb_force_makefs->isChecked())
         options += "--force=makefs ";
-    }
-    if (ui->cb_force_nofuse->isChecked()) {
+    if (ui->cb_force_nofuse->isChecked())
         options += "--force=nofuse ";
-    }
     if (ui->rb_dd->isChecked()) {
 
     }
 
-    if (ui->cb_data_first->isChecked()) {
+    if (ui->cb_data_first->isChecked())
         options += "--data-first=" + ui->spinBoxDataSize->cleanText() + "," + ui->comboBoxDataFormat->currentText() + " ";
-    }
-    switch(ui->sliderVerbosity->value()) {
+
+    switch(ui->sliderVerbosity->value())
+    {
     case 1 : options += "-V ";
         break;
     case 2 : options += "-VV ";
@@ -274,17 +262,12 @@ QStringList MainWindow::removeUnsuitable(const QStringList &devices)
     QString name;
     for (const QString &line : devices) {
         name = line.split(" ").at(0);
-        if (ui->cb_force_usb->isChecked()){
-            if (cmd.getCmdOut(cli_utils + "get_drive $(get_live_dev) ") != name) {
+        if (ui->cb_force_usb->isChecked()) {
+            if (cmd.getCmdOut(cli_utils + "get_drive $(get_live_dev) ") != name)
+                list << line;
+        } else if (system(cli_utils.toUtf8() + "is_usb_or_removable " + name.toUtf8()) == 0)
+            if (cmd.getCmdOut(cli_utils + "get_drive $(get_live_dev) ") != name)
                 list << line;
-            }
-        } else {
-            if (system(cli_utils.toUtf8() + "is_usb_or_removable " + name.toUtf8()) == 0) {
-                if (cmd.getCmdOut(cli_utils + "get_drive $(get_live_dev) ") != name) {
-                    list << line;
-                }
-            }
-        }
     }
     return list;
 }
@@ -302,11 +285,10 @@ void MainWindow::cmdDone()
     ui->progressBar->setValue(ui->progressBar->maximum());
     setCursor(QCursor(Qt::ArrowCursor));
     ui->buttonBack->show();
-    if (cmd.exitCode() == 0 && cmd.exitStatus() == QProcess::NormalExit) {
+    if (cmd.exitCode() == 0 && cmd.exitStatus() == QProcess::NormalExit)
         QMessageBox::information(this, tr("Success"), tr("LiveUSB creation successful!"));
-    } else {
+    else
         QMessageBox::critical(this, tr("Failure"), tr("Error encountered in the LiveUSB creation process"));
-    }
     cmd.disconnect();
 }
 
@@ -323,7 +305,7 @@ void MainWindow::setConnections()
 // set proper default mode based on iso contents
 void MainWindow::setDefaultMode(const QString &iso_name)
 {
-    if (!isantiX_mx_family(iso_name)){
+    if (!isantiX_mx_family(iso_name)) {
         ui->rb_dd->click();
         ui->rb_normal->setChecked(false);
     } else {
@@ -378,10 +360,7 @@ void MainWindow::on_buttonNext_clicked()
         }
         ui->buttonNext->setEnabled(false);
         ui->stackedWidget->setCurrentWidget(ui->outputPage);
-
         makeUsb(buildOptionList());
-
-    // on output page
     } else if (ui->stackedWidget->currentWidget() == ui->outputPage) {
 
     } else {
@@ -416,7 +395,7 @@ void MainWindow::on_buttonAbout_clicked()
 // Help button clicked
 void MainWindow::on_buttonHelp_clicked()
 {
-    QString url = "/usr/share/doc/live-usb-maker-gui-antix/help/live-usb-maker-gui-antix.html";
+    QString url = "/usr/share/doc/live-usb-maker-gui-antix/live-usb-maker-gui-antix.html";
     displayDoc(url, tr("%1 Help").arg(this->windowTitle()), true);
 }
 
@@ -523,7 +502,7 @@ void MainWindow::on_cb_clone_mode_clicked(bool checked)
 
 void MainWindow::on_cb_clone_live_clicked(bool checked)
 {
-    if (checked){
+    if (checked) {
         ui->buttonSelectSource->setStyleSheet("text-align: center;");
         ui->cb_clone_mode->setChecked(false);
         ui->label_3->setText("<b>" + tr("Select Source") + "</b>");
@@ -579,35 +558,24 @@ bool MainWindow::isantiX_mx_family(QString selected)
 {
     QString cmdstr;
 
-    //make temp folder
-    cmdstr = "mkdir -p /tmp/testisomount";
-
-    if ( system(cmdstr.toUtf8()) != 0 ){
+    // make temp folder
+    QTemporaryDir tmpdir;
+    if (!tmpdir.isValid()) {
+        qDebug() << "Could not create temp folder";
         return false;
     }
 
-    //mount the iso file
-    cmdstr = "mount -o loop " + selected + " /tmp/testisomount";
+    // mount the iso file
+    cmdstr = "mount -o loop " + selected + " " + tmpdir.path();
     if (system(cmdstr.toUtf8()) != 0) {
-        //cleanup mount point
-        cmdstr = "rmdir /tmp/testisomount";
-        system(cmdstr.toUtf8());
+        qDebug() << "Could not mount iso file to temp folder";
         return false;
     }
 
-    //check for antiX folder - this is a BS check but works for now since no antiX family iso doens't have an antiX folder
-    cmdstr = "ls /tmp/testisomount |grep antiX";
-    if (system(cmdstr.toUtf8()) == 0){
-        //mean found
-        //cleanup mount
-        cmdstr = "umount /tmp/testisomount; rmdir /tmp/testisomount";
-        system(cmdstr.toUtf8());
-        return true;
-    } else {
-        cmdstr = "umount /tmp/testisomount; rmdir /tmp/testisomount";
-        system(cmdstr.toUtf8());
-        return false;
-    }
+    // check for antiX folder - this is a BS check but works for now since no antiX family iso doens't have an antiX folder
+    bool test = QFileInfo::exists(tmpdir.path() + "/antiX");
+    system("umount " + tmpdir.path().toUtf8());
+    return test;
 }
 
 void MainWindow::on_pushButtonLumLogFile_clicked()
@@ -628,16 +596,14 @@ void MainWindow::on_pushButtonLumLogFile_clicked()
     cmd = "tac /var/log/" + lum.baseName() + ".log | sed \"/^=\\{60\\}=*$/q\" > /tmp/" + lum.baseName() + ".log";
     system(cmd.toUtf8());
 
-    if (getuid() == 0) {
+    if (getuid() == 0)
         rootrunoption = "runuser -l $(logname) -c ";
-    }
 
-    if (viewer.exists()) {
+    if (viewer.exists())
         cmd = QString("mx-viewer %1 '%2' &").arg(url).arg(lum.baseName());
-    } else if (viewer2.exists()) {
+    else if (viewer2.exists())
         cmd = QString("antix-viewer %1 '%2' &").arg(url).arg(lum.baseName());
-    } else {
+    else
         cmd = QString(rootrunoption + "\"DISPLAY=$DISPLAY xdg-open %1\" &").arg(url);
-    }
     system(cmd.toUtf8());
 }
